@@ -9,23 +9,10 @@ Top level module for exposing the public API of usable modules
 """
 from . import plots
 from . import magnets
-from .magnets._magnet import reset_magnets, list_magnets
-from .magnets._routines2 import grid2D, B_calc_2D
-from .magnets._routines3 import grid3D, B_calc_3D
-from math import pi as PI
+from . import utils
+from . import forces
+from .magnets._magnet_base import reset_magnets, list_magnets
+from .utils._routines2D import grid2D, get_field_2D
+from .utils._routines3D import grid3D, slice3D, get_field_3D
 
-"""float: Module level PI.
-"""
-
-PI_2 = PI / 2.0
-"""float: Module level PI/2.
-"""
-PI_4 = PI / 4.0
-"""float: Module level PI/4.
-"""
-
-u0 = 4e-7 * PI
-"""float: Module level u0, permittivity of free space.
-"""
-
-__all__ = ["magnets", "plots"]
+__all__ = ["magnets", "plots", "utils"]
